module Core.Configuration where

import Configuration.Dotenv

import System.Directory   (doesFileExist)
import System.Environment (getEnv, lookupEnv)

-- Load environment variables from dotenv file if any are missing from ENV
main :: IO ()
main = do
  reqEnvLookup <- getRequiredEnv
  if (Nothing `elem` reqEnvLookup)
    then checkEnvFile requiredEnvVars
    else pure ()
  where
    getRequiredEnv :: IO [Maybe String]
    getRequiredEnv = mapM (\s -> lookupEnv s) requiredEnvVars

    checkEnvFile :: [String] -> IO ()
    checkEnvFile requiredEnv = do
      dotEnvExists <- doesFileExist "./.env"
      if dotEnvExists
        then do
          loadFile defaultConfig
          fromEnvFile <- getRequiredEnv
          if (Nothing `elem` fromEnvFile)
             then error $ missingEnvMsg requiredEnv
             else pure ()
        else error $ "Cannot find .env file in application directory.\n"
          ++ missingEnvMsg requiredEnv

    missingEnvMsg :: [String] -> String
    missingEnvMsg required =
      "Missing required environment variable(s).\n"
      ++ "All required environment variables:\n"
      ++  unlines required

appPort :: IO String
appPort = getEnv "APPLICATIONPORT"

appTitle :: IO String
appTitle = getEnv "BLOGTITLE"

requiredEnvVars :: [String]
requiredEnvVars = [ "APPLICATIONPORT", "BLOGTITLE" ]
