module Core.Feed where

import           Data.Maybe
import           Data.Text

import qualified Data.Text.Lazy   as LT
import qualified Text.Atom.Feed   as Atom
import qualified Text.Feed.Export as Export (textFeedWith)
import           Text.Feed.Types
import           Text.XML (def, rsPretty)

data Post = Post { _date     :: Text
                 , _url      :: Text
                 , _content  :: Text
                 }

-- Automatically populate Atom Feed with entries
autoFeed :: Atom.Feed -> [Post] -> Atom.Feed
autoFeed baseFeed feedData = baseFeed { Atom.feedEntries = fmap toEntry feedData }

-- Render the Atom Feed to Lazy Text
renderFeed :: Atom.Feed -> LT.Text
renderFeed = fromJust . Export.textFeedWith def{rsPretty = True} . AtomFeed

-- Convert a Post to an Atom Entry
toEntry :: Post -> Atom.Entry
toEntry (Post date url content) = (Atom.nullEntry url (Atom.TextString content) date)
