module Core.HTTP where

import qualified Core.Configuration                   as Conf
import qualified Core.Handlers                        as Handle

import           Control.Monad                        ( mapM_ )
import           Data.String                          ( fromString )
import           Network.Wai.Handler.Warp             ( Port, run )
import           Network.Wai.Middleware.RequestLogger ( logStdoutDev )
import           Network.Wai.Middleware.Static
import           System.FilePath                      ( takeFileName )


import           Web.Twain

-- Get the port to listen on from the ENV and start the webserver.
main :: [FilePath] -> IO ()
main postNames = do
  port <- Conf.appPort
  let app = preProcessors 
         ++ (routes postNames)
         ++ postProcessors
  run (read port) $ 
    foldr ($) (notFound Handle.missing) app

-- These Middlewares are executed before any routes are reached.
preProcessors :: [Middleware]
preProcessors = [ logStdoutDev ]

-- These Middlewares are executed after all other routes are exhausted
postProcessors :: [Middleware]
postProcessors = []

{- The application's core routes expressed as a list of WAI Middlewares.
   The list of post names is required so that the postsIndex handler can
   automatically build an index of posts available to view. -}
routes :: [FilePath] -> [Middleware]
routes postNames  =
  [ get "/"            Handle.index 
  , get "/posts"     $ Handle.postsIndex postNames
  , get "/style.css" $ Handle.theme
  ]                 ++ handleDynamicPosts ++
  [ get "/contact"     Handle.contact
  , get "/feed"      $ Handle.feed postNames
  , get "/atom.xml"  $ Handle.feed postNames
  ] where 
      handleDynamicPosts = (buildMdRoutes postNames)

-- Takes a post's name extracted from the filepath and returns a valid route
mdFileToRoute :: FilePath -> Middleware
mdFileToRoute postName = get (fromString $ "/posts/" ++ postName) (Handle.posts postName)

buildMdRoutes :: [FilePath] -> [Middleware]
buildMdRoutes postNames = map mdFileToRoute postNames
