module Main where

import qualified Core.HTTP            as HTTP
import qualified Core.Configuration   as Conf

import           Control.Monad        ( mapM_ )
import           System.FilePath.Find ( always, extension, fileName, find, (&&?)
                                      , (/~?), (==?) )
import           System.FilePath      ( dropExtension, takeFileName )


main :: IO ()
main = do
  Conf.main 
  mdFilePaths <- getMdFilePaths "./data/posts/"
  -- Pass only the post names extracted from their filepath to HTTP.main
  let mdFiles =  map (dropExtension . takeFileName) mdFilePaths
  HTTP.main mdFiles

-- Return a list of all non-hidden .md files except for home.md and contact.md
getMdFilePaths :: FilePath -> IO [FilePath]
getMdFilePaths fp = find isVisible fileFilter fp
  where
    isMdFile   = extension ==? ".md"
    isVisible  = fileName  /~? ".?*"
    isHome     = fileName  /~? "home.md"
    isContact  = fileName  /~? "contact.md"
    isFooter   = fileName  /~? "footer.md"
    fileFilter = isMdFile 
             &&? isVisible 
             &&? isHome 
             &&? isContact 
             &&? isFooter
